@@ -19,6 +19,6 @@ def main():
     for directory in directories:
         print directory
         print getoutput('svn up %s' % directory)
-        print getoutput('svn log -l 1 %s' % directory)
+        print getoutput('svn log --limit 1 %s' % directory)
         print
         print
